<?php

	class Metrika_Api
	{
		private $options;
		private $token;

		public function __construct($options)
		{
			$this->options = $options;
			$this->token = null;
			
			if($this->getToken() != true) exit('Ошибка: Невозможно получить значение токена авторизации!');
		}
		
		private function getToken()
		{
			$url = 'https://oauth.yandex.ru/token';
			
			$options = array(
				'grant_type' => 'password',
				'username' => $this->options['login'],
				'password' => $this->options['password'],
				'client_id' => $this->options['yandex_app_id'],
				'client_secret' => $this->options['yandex_app_secret']
			);
			
			$curl = curl_init();
			
			curl_setopt($curl, CURLOPT_URL, $url);
			curl_setopt($curl, CURLOPT_HEADER, 1);
			curl_setopt($curl, CURLOPT_POST, 1);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
			curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($options));
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
			
			$response = curl_exec($curl);
			
			if(0 !== curl_errno($curl) || 200 !== curl_getinfo($curl, CURLINFO_HTTP_CODE)) return false;
			
			curl_close($curl);
			
			if(preg_match('%"access_token": "([0-9a-z]+)"%usi', $response, $m) == true)
			{
				$this->token = $m[1]; return true;
			}
			
			return false;
		}
		
		private function setRequest($method_type = '', $method_name = '', $options = array())
		{
			$url = 'https://api-metrika.yandex.ru/' . $method_name . '.json';
			
			$curl = curl_init();
			
			if($method_type != 'GET')
			{
				curl_setopt($curl, CURLOPT_POST, 1);
				curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($options));
			}
			else
			{
				if(count($options) > 0) $url .= '?' . http_build_query($options);
			}

			curl_setopt($curl, CURLOPT_URL, $url);
			curl_setopt($curl, CURLOPT_HEADER, 0);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($curl, CURLOPT_CUSTOMREQUEST, $method_type);

			$response = curl_exec($curl);
			
			if(0 !== curl_errno($curl) || 200 !== curl_getinfo($curl, CURLINFO_HTTP_CODE)) return false;
			
			curl_close($curl);

			return json_decode($response, true);
		}

		public function get_all_counters()
		{
			return $this->setRequest('GET', 'counters', array('pretty' => 1, 'oauth_token' => $this->token));
		}

		public function count_counters()
		{
			$counters = $this->get_all_counters();
			
			return $counters['rows'];
		}

		public function get_counters()
		{
			$results = $this->get_all_counters();
		
			return $results['counters'];
		}

		public function is_valid_counter($counter_id)
		{
			$current_counter = $this->fetch_counter($counter_id);

			if($current_counter['counter']['code_status'] == 'CS_OK') return true;

			return false;
		}

		public function fetch_counter($counter_id)
		{
			return $this->setRequest('GET', 'counter/' . $counter_id, array('pretty' => 1, 'oauth_token' => $this->token));
		}

		public function get_counter_name($counter_id)
		{
			$current_counter = $this->fetch_counter($counter_id);
			
			return $current_counter['counter']['name'];
		}

		public function get_counter_statistics($counter_id, $start_date, $end_date, $value = null)
		{
			$statistics = $this->setRequest('GET', 'stat/traffic/summary', array('id' => $counter_id, 'date1' => $start_date, 'date2' => $end_date, 'pretty' => 1, 'oauth_token' => $this->token));

			if(is_null($value) == true) return $statistics;
			
			return $statistics[$value];
		}

		public function get_popular_content($counter_id, $start_date, $end_date, $per_page = 5)
		{
			return $this->setRequest('GET', 'stat/traffic/popular', array('id' => $counter_id, 'date1' => $start_date, 'date2' => $end_date, 'per_page' => $per_page, 'pretty' => 1, 'oauth_token' => $this->token));
		}

		public function get_referal_sites($counter_id, $start_date, $end_date, $per_page = 5)
		{
			return $this->setRequest('GET', 'stat/sources/sites', array('id' => $counter_id, 'date1' => $start_date, 'date2' => $end_date, 'per_page' => $per_page, 'pretty' => 1, 'oauth_token' => $this->token));
		}

		public function get_search_terms($counter_id, $start_date, $end_date, $per_page = 5)
		{
			return $this->setRequest('GET', 'stat/sources/phrases', array('id' => $counter_id, 'date1' => $start_date, 'date2' => $end_date, 'per_page' => $per_page, 'pretty' => 1, 'oauth_token' => $this->token));
		}

	}

?>